@@ -13,6 +13,10 @@
 #' calculate it as \code{sqrt(mean(x^2))}, where \code{x} is your waveform.
 #' Having RMS estimates per frame gives more flexibility: RMS per sound can be
 #' calculated as the mean / median / max of RMS values per frame.
+#'
+#' @seealso \code{\link{getRMSFolder}}
+#'   \code{\link{analyze}}\code{\link{getLoudness}}
+#'
 #' @inheritParams spectrogram
 #' @param scale maximum possible amplitude of input used for normalization (not
 #'   needed for audio files)
@@ -80,7 +84,7 @@ getRMS = function(x,
       step = round(windowLength * (1 - overlap / 100))
     }
     if (windowLength_points == 0) {
-      stop('The sound and/or the windowLength is too short for plotting a spectrogram')
+      stop('The sound and/or the windowLength is too short')
     }
     duration = length(sound) / samplingRate
   } else if (class(x) == 'numeric' & length(x) > 1) {
@@ -143,6 +147,9 @@ getRMS = function(x,
 #' or, if \code{summary = TRUE}, a dataframe with a single summary value of RMS
 #' per file. This summary value can be mean, max and so on, as per
 #' \code{summaryFun}.
+#'
+#' @seealso \code{\link{getRMS}} \code{\link{analyze}}\code{\link{getLoudness}}
+#'
 #' @param myfolder path to folder containing wav/mp3 files
 #' @inheritParams getRMS
 #' @param summary if TRUE, returns only a single value of RMS per file
@@ -241,6 +248,9 @@ getRMSFolder = function(myfolder,
 #' loudness of each sound is estimated by \code{\link{getLoudness}}, which
 #' assumes frequency sensitivity typical of human hearing. The following
 #' normalization procedure is similar to that for \code{type = 'rms'}.
+#'
+#' @seealso \code{\link{getRMS}} \code{\link{analyze}}\code{\link{getLoudness}}
+#'
 #' @inheritParams getRMSFolder
 #' @param type normalize so the output files has the same peak amplitude
 #'   ('peak'), root mean square amplitude ('rms'), or subjective loudness in
