@@ -7,10 +7,20 @@
 #' routines for noise reduction, smoothing in time and frequency domains, manual
 #' control of contrast and brightness, plotting the oscillogram on a dB scale,
 #' grid, etc.
+#'
+#' Many soundgen functions call \code{spectrogram}, and you can pass along most
+#' of its graphical parameters from functions like \code{\link{soundgen}},
+#' \code{\link{analyze}}, etc. However, in some cases this will not work (eg for
+#' "units") or may produce unexpected results. If in doubt, omit extra graphical
+#' parameters.
+#'
+#' @seealso \code{\link{modulationSpectrum}} \code{\link{ssm}}
+#'   \code{\link{osc_dB}}
+#'
 #' @param x path to a .wav or .mp3 file or a vector of amplitudes with specified
 #'   samplingRate
-#' @param samplingRate sampling rate of \code{x} (only needed if
-#'   \code{x} is a numeric vector, rather than an audio file)
+#' @param samplingRate sampling rate of \code{x} (only needed if \code{x} is a
+#'   numeric vector, rather than an audio file)
 #' @param dynamicRange dynamic range, dB. All values more than one dynamicRange
 #'   under maximum are treated as zero
 #' @param windowLength length of FFT window, ms
@@ -19,16 +29,17 @@
 #' @param wn window type: gaussian, hanning, hamming, bartlett, rectangular,
 #'   blackman, flattop
 #' @param normalize if TRUE, scales input prior to FFT
+#' @param scale maximum possible amplitude of input used for normalization of
+#'   input vector (not needed if input is an audio file)
 #' @param zp window length after zero padding, points
 #' @param smoothFreq,smoothTime length of the window, in data points (0 to
 #'   +inf), for calculating a rolling median. Applies median smoothing to
 #'   spectrogram in frequency and time domains, respectively
-#' @param qTime the quantile to be subtracted for each frequency
-#'   bin. For ex., if qTime = 0.5, the median of each frequency
-#'   bin (over the entire sound duration) will be calculated and subtracted from
-#'   each frame (see examples)
-#' @param percentNoise percentage of frames (0 to 100\%) used for calculating noise
-#'   spectrum
+#' @param qTime the quantile to be subtracted for each frequency bin. For ex.,
+#'   if qTime = 0.5, the median of each frequency bin (over the entire sound
+#'   duration) will be calculated and subtracted from each frame (see examples)
+#' @param percentNoise percentage of frames (0 to 100\%) used for calculating
+#'   noise spectrum
 #' @param noiseReduction how much noise to remove (0 to +inf, recommended 0 to
 #'   2). 0 = no noise reduction, 2 = strong noise reduction: \eqn{spectrum -
 #'   (noiseReduction * noiseSpectrum)}, where noiseSpectrum is the average
@@ -45,25 +56,32 @@
 #'   ('processed'), or unmodified spectrogram with the imaginary part giving
 #'   phase ('complex')
 #' @param ylim frequency range to plot, kHz (defaults to 0 to Nyquist frequency)
+#' @param yScale scale of the frequency axis: 'linear' = linear, 'log' =
+#'   logarithmic
 #' @param plot should a spectrogram be plotted? TRUE / FALSE
 #' @param osc,osc_dB should an oscillogram be shown under the spectrogram? TRUE/
 #'   FALSE. If `osc_dB`, the oscillogram is displayed on a dB scale. See
 #'   \code{\link{osc_dB}} for details
 #' @param heights a vector of length two specifying the relative height of the
-#'   spectrogram and the oscillogram
+#'   spectrogram and the oscillogram (including time axes labels)
+#' @param padWithSilence if TRUE, pads the sound with just enough silence to
+#'   resolve the edges properly (only the original region is plotted, so
+#'   apparent duration doesn't change)
 #' @param colorTheme black and white ('bw'), as in seewave package ('seewave'),
-#'   or any palette from \code{\link[grDevices]{palette}} such as
-#'   'heat.colors', 'cm.colors', etc
+#'   or any palette from \code{\link[grDevices]{palette}} such as 'heat.colors',
+#'   'cm.colors', etc
+#' @param units c('ms', 'kHz') is the default, and anything else is interpreted
+#'   as s (for time) and Hz (for frequency)
 #' @param xlab,ylab,main,mar graphical parameters
 #' @param grid if numeric, adds n = \code{grid} dotted lines per kHz
 #' @param ... other graphical parameters
-#' @param frameBank ignore (only needed for pitch tracking)
-#' @param duration ignore (only needed for pitch tracking)
+#' @param frameBank,duration,pitch ignore (only used internally)
 #' @export
 #' @return Returns nothing (if output = 'none'), absolute - not power! -
 #'   spectrum (if output = 'original'), denoised and/or smoothed spectrum (if
 #'   output = 'processed'), or spectral derivatives (if method =
 #'   'spectralDerivative') as a matrix of real numbers.
+#' @seealso \code{\link{modulationSpectrum}} \code{\link{ssm}}
 #' @examples
 #' # synthesize a sound 1 s long, with gradually increasing hissing noise
 #' sound = soundgen(sylLen = 1000, temperature = 0.001, noise = list(
@@ -76,12 +94,16 @@
 #'
 #' # add bells and whistles
 #' spectrogram(sound, samplingRate = 16000,
-#'   osc = TRUE, noiseReduction = 1.1,
-#'   brightness = -1, colorTheme = 'heat.colors',
-#'   ylim = c(0, 5), cex.lab = .75,
-#'   main = 'My spectrogram',
-#'   yaxp = c(0, 8, 16),  # tip: for base graphics, see ?par
-#'   grid = 5  # tip: to customize, add manually with graphics::grid()
+#'   osc = TRUE,  # plot oscillogram under the spectrogram
+#'   noiseReduction = 1.1,  # subtract the spectrum of noisy parts
+#'   brightness = -1,  # reduce brightness
+#'   colorTheme = 'heat.colors',  # pick color theme
+#'   cex.lab = .75, cex.axis = .75,  # text size and other base graphics pars
+#'   grid = 5,  # lines per kHz; to customize, add manually with graphics::grid()
+#'   units = c('s', 'Hz'),  # plot in s or ms, Hz or kHz
+#'   ylim = c(0, 5000),  # in specified units (Hz)
+#'   main = 'My spectrogram' # title
+#'   # + axis labels, etc
 #' )
 #'
 #' \dontrun{
@@ -96,6 +118,10 @@
 #' spectrogram(sound, samplingRate = 16000,
 #'             osc_dB = TRUE, heights = c(1, 1))
 #'
+#' # frequencies on a logarithmic scale
+#' spectrogram(sound, samplingRate = 16000,
+#'             yScale = 'log', ylim = c(.05, 8))
+#'
 #' # broad-band instead of narrow-band
 #' spectrogram(sound, samplingRate = 16000, windowLength = 5)
 #'
@@ -113,39 +139,50 @@
 #'
 #' # increase contrast, reduce brightness
 #' spectrogram(sound, samplingRate = 16000, contrast = 1, brightness = -1)
+#'
+#' # specify location of tick marks etc - see ?par() for base graphics
+#' spectrogram(sound, samplingRate = 16000,
+#'             ylim = c(0, 3), yaxp = c(0, 3, 5), xaxp = c(0, 1400, 4))
 #' }
-spectrogram = function(x,
-                       samplingRate = NULL,
-                       dynamicRange = 80,
-                       windowLength = 50,
-                       step = NULL,
-                       overlap = 70,
-                       wn = 'gaussian',
-                       zp = 0,
-                       normalize = TRUE,
-                       smoothFreq = 0,
-                       smoothTime = 0,
-                       qTime = 0,
-                       percentNoise = 10,
-                       noiseReduction = 0,
-                       contrast = .2,
-                       brightness = 0,
-                       method = c('spectrum', 'spectralDerivative')[1],
-                       output = c('none', 'original', 'processed', 'complex')[1],
-                       ylim = NULL,
-                       plot = TRUE,
-                       osc = FALSE,
-                       osc_dB = FALSE,
-                       heights = c(3, 1),
-                       colorTheme = c('bw', 'seewave', '...')[1],
-                       xlab = 'Time, ms',
-                       ylab = 'Frequency, kHz',
-                       mar = c(5.1, 4.1, 4.1, 2),
-                       main = '',
-                       grid = NULL,
-                       frameBank = NULL,
-                       duration = NULL,
-                       ...) {
+spectrogram = function(
+  x,
+  samplingRate = NULL,
+  dynamicRange = 80,
+  windowLength = 50,
+  step = NULL,
+  overlap = 70,
+  wn = 'gaussian',
+  zp = 0,
+  normalize = TRUE,
+  scale = NULL,
+  smoothFreq = 0,
+  smoothTime = 0,
+  qTime = 0,
+  percentNoise = 10,
+  noiseReduction = 0,
+  contrast = .2,
+  brightness = 0,
+  method = c('spectrum', 'spectralDerivative')[1],
+  output = c('original', 'processed', 'complex')[1],
+  ylim = NULL,
+  yScale = c('linear', 'log')[1],
+  plot = TRUE,
+  osc = FALSE,
+  osc_dB = FALSE,
+  heights = c(3, 1),
+  padWithSilence = TRUE,
+  colorTheme = c('bw', 'seewave', 'heat.colors', '...')[1],
+  units = c('ms', 'kHz'),
+  xlab = paste('Time,', units[1]),
+  ylab = paste('Frequency,', units[2]),
+  mar = c(5.1, 4.1, 4.1, 2),
+  main = '',
+  grid = NULL,
+  frameBank = NULL,
+  duration = NULL,
+  pitch = NULL,
+  ...
+) {
   sound = NULL
   if (overlap < 0 | overlap > 100) {
     warning('overlap must be >0 and <= 100%; resetting to 70')
@@ -183,14 +220,19 @@ spectrogram = function(x,
       zp = zp,
       normalize = normalize,
       wn = wn,
-      filter = NULL
+      filter = NULL,
+      padWithSilence = padWithSilence
     )
   } else if (class(x) == 'numeric' & length(x) > 1) {
     if (is.null(samplingRate)) {
       stop ('Please specify samplingRate, eg 44100')
     } else {
       sound = x
-      maxAmpl = max(abs(sound))
+      if (is.null(scale)) {
+        maxAmpl = max(abs(sound))
+      } else {
+        maxAmpl = scale
+      }
       duration = length(sound) / samplingRate
       windowLength_points = floor(windowLength / 1000 * samplingRate / 2) * 2
       if (windowLength_points > (length(sound) / 2)) {
@@ -201,14 +243,15 @@ spectrogram = function(x,
         stop('The sound and/or the windowLength is too short for plotting a spectrogram')
       }
       frameBank = getFrameBank(
-        sound = x,
+        sound = sound,
         samplingRate = samplingRate,
         windowLength_points = windowLength_points,
         step = step,
         zp = zp,
         normalize = normalize,
         wn = wn,
-        filter = NULL
+        filter = NULL,
+        padWithSilence = padWithSilence
       )
     }
   }
@@ -221,7 +264,11 @@ spectrogram = function(x,
 
   # fix default settings
   if (is.null(ylim)) {
-    ylim = c(0, samplingRate / 2 / 1000)
+    if (units[2] == 'kHz') {
+      ylim = c(0, samplingRate / 2 / 1000)
+    } else {
+      ylim = c(0, samplingRate / 2)
+    }
   }
   contrast_exp = exp(3 * contrast)
   brightness_exp = exp(3 * brightness)
@@ -244,23 +291,18 @@ spectrogram = function(x,
   if (!is.matrix(z)) z = matrix(z, ncol = 1)
   # adjust the timing of spectrogram to match the actual time stamps
   # in getFrameBank (~the middle of each fft frame)
-  if (!is.null(sound)) {
-    X = seq(1, max(1, (length(sound) - windowLength_points)),
-            step / 1000 * samplingRate) / samplingRate * 1000 + windowLength / 2
-  } else {
-    # if calling spectrogram from analyze() with only frameBank
-    X = seq(0, duration * 1000 - windowLength,
-            length.out = ncol(z)) + windowLength / 2
-  }
+  X = as.numeric(colnames(frameBank))
   if (length(X) < 2) {
-    stop('The sound is too short for plotting a spectrogram')
+    message('The sound is too short for plotting a spectrogram')
+    return(NA)
   }
   bin_width = samplingRate / 2 / windowLength_points
   Y = seq(bin_width / 2,
           samplingRate / 2 - bin_width / 2,
           length.out = nrow(z)) / 1000  # frequency stamp
   if (length(Y) < 2) {
-    stop('The sound and/or the windowLength is too short for plotting a spectrogram')
+    message('The sound and/or the windowLength is too short for plotting a spectrogram')
+    return(NA)
   }
   rownames(z) = Y
   colnames(z) = X
@@ -337,15 +379,7 @@ spectrogram = function(x,
 
   if (plot) {
     # spectrogram of the modified fft
-    if (colorTheme == 'bw') {
-      color.palette = function(x) gray(seq(from = 1, to = 0, length = x))
-    } else if (colorTheme == 'seewave') {
-      color.palette = seewave::spectro.colors
-    } else {
-      colFun = match.fun(colorTheme)
-      color.palette = function(x) rev(colFun(x))
-    }
-
+    color.palette = switchColorTheme(colorTheme)
     op = par(c('mar', 'xaxt', 'yaxt', 'mfrow')) # save user's original pars
     if (osc | osc_dB) {
       if (osc_dB) {
@@ -360,18 +394,23 @@ spectrogram = function(x,
       }
       layout(matrix(c(2, 1), nrow = 2, byrow = TRUE), heights = heights)
       par(mar = c(mar[1:2], 0, mar[4]), xaxt = 's', yaxt = 's')
+      if (units[1] == 'ms') {
+        time_stamps = seq(0, duration * 1000, length.out = length(sound))
+      } else {
+        time_stamps = seq(0, duration, length.out = length(sound))
+      }
       plot(
-        seq(0, duration * 1000, length.out = length(sound)),
+        time_stamps,
         sound,
         type = "l",
         ylim = ylim_osc,
         axes = FALSE, xaxs = "i", yaxs = "i", bty = 'o',
         xlab = xlab, ylab = '', main = '', ...)
       box()
-      axis(side = 1)
+      axis(side = 1, ...)
       if (osc_dB) {
-        axis(side = 4, at = seq(0, dynamicRange, by = 10))
-        mtext("dB", side = 2, line = 3)
+        axis(side = 4, at = seq(0, dynamicRange, by = 10), ...)
+        mtext("dB", side = 2, line = 3, ...)
       }
       abline(h = 0, lty = 2)
       par(mar = c(0, mar[2:4]), xaxt = 'n', yaxt = 's')
@@ -380,31 +419,51 @@ spectrogram = function(x,
       par(mar = mar)
     }
 
+    min_log_freq = ifelse(units[2] == 'kHz', .01, 10)
+    if (yScale == 'log' & ylim[1] < min_log_freq)  ylim[1] = min_log_freq
+    if (units[1] == 'ms') {
+      xlim = c(0, duration * 1000)
+    } else {
+      X = X / 1000
+      xlim = c(0, duration)
+    }
+    if (units[2] != 'kHz') Y = Y * 1000
     filled.contour.mod(
       x = X, y = Y, z = Z1,
       levels = seq(0, 1, length = 30),
       color.palette = color.palette,
       ylim = ylim, main = main,
       xlab = xlab, ylab = ylab,
-      xlim = c(0, duration * 1000),
+      xlim = xlim,
+      log = ifelse(yScale == 'log', 'y', ''),
       ...
     )
     if (is.numeric(grid)) {
       n_grid_per_kHz = diff(range(ylim)) * grid
+      if (units[2] != 'kHz') n_grid_per_kHz = n_grid_per_kHz / 1000
       grid(nx = n_grid_per_kHz, ny = n_grid_per_kHz,
            col = rgb(0, 0, 0, .25, maxColorValue = 1), lty = 3)
+      # grid(nx = NULL, ny = NULL,
+      #      col = rgb(0, 0, 0, .25, maxColorValue = 1), lty = 3,
+      #      equilogs = TRUE)
+    }
+    if (!is.null(pitch)) {
+      do.call(addPitchCands, pitch)
     }
     # restore original pars
     par('mar' = op$mar, 'xaxt' = op$xaxt, 'yaxt' = op$yaxt, 'mfrow' = op$mfrow)
   }
 
   if (output == 'original') {
-    return(t(Z))  # before denoising
+    out = t(Z)  # before denoising
   } else if (output == 'processed') {
-    return(t(Z1))  # denoised spectrum / spectralDerivative
+    out = t(Z1)  # denoised spectrum / spectralDerivative
   } else if (output == 'complex') {
-    return(z)  # with the imaginary part
+    out = z  # with the imaginary part
+  } else {
+    out = NULL
   }
+  invisible(out)
 }
 
 
@@ -462,8 +521,8 @@ spectrogramFolder = function(myfolder,
     # remove file extension
     f = substr(as.character(filenames[i]), 1, nchar(as.character(filenames[i])) - 4)
     png(filename = paste0(f, ".png"),
-         width = width, height = height,
-         units = units, res = res)
+        width = width, height = height,
+        units = units, res = res)
     do.call(spectrogram, list(
       x = filenames[i],
       windowLength = windowLength,
@@ -562,20 +621,33 @@ getFrameBank = function(sound,
                         step,
                         zp,
                         normalize = TRUE,
-                        filter = NULL) {
+                        filter = NULL,
+                        padWithSilence = FALSE) {
   # # normalize to range from no less than -1 to no more than +1
-  if (!is.numeric(sound)) {
-    return(NA)
-  }
-  if (any(is.na(sound))) {
-    sound[is.na(sound)] = 0
-  }
+  if (!is.numeric(sound)) return(NA)
+  sound[is.na(sound)] = 0
   if (normalize & any(sound != 0)) {
     sound = sound - mean(sound)
     sound = sound / max(abs(max(sound)), abs(min(sound)))
   }
+  step_points = round(step / 1000 * samplingRate)
+
+  if (padWithSilence) {
+    # pad with silence to make sure edges are properly analyzed
+    sound = c(rep(0, windowLength_points / 2),
+              sound,
+              rep(0, (windowLength_points + step_points)))
+  }
   myseq = seq(1, max(1, (length(sound) - windowLength_points)),
-              step / 1000 * samplingRate)
+              by = step_points)
+  if (padWithSilence) {
+    time_stamps = (myseq - 1) *
+      1000 / samplingRate
+  } else {
+    time_stamps = (myseq - 1 + windowLength_points / 2) *
+      1000 / samplingRate
+  }
+
   if (is.null(filter)) {
     filter = ftwindow_modif(wl = windowLength_points, wn = wn)
   }
@@ -592,6 +664,7 @@ getFrameBank = function(sound,
       sound[x:(windowLength_points + x - 1)] * filter
     })
   }
+  colnames(frameBank) = time_stamps
   return(frameBank)
 }
 
@@ -610,32 +683,42 @@ getFrameBank = function(sound,
 #' @param nlevels numbers of levels for partitioning z
 #' @param color.palette color palette function
 #' @param col list of colors instead of color.palette
-#' @param asp,xaxs,yaxs,... graphical parameters passed to plot.window() and axis()
+#' @param asp,xaxs,yaxs,... graphical parameters passed to plot.window() and
+#'   axis()
+#' @param axisX,axisY plot the axis or not (logical)
+#' @param log log = 'y' log-transforms the y axis
 #' @keywords internal
-filled.contour.mod = function(x = seq(0, 1, len = nrow(z)),
-                              y = seq(0, 1, len = ncol(z)),
-                              z,
-                              xlim = range(x, finite = TRUE),
-                              ylim = range(y, finite = TRUE),
-                              zlim = range(z, finite = TRUE),
-                              levels = pretty(zlim, nlevels),
-                              nlevels = 30,
-                              color.palette = function(n) hcl.colors(n, "YlOrRd", rev = TRUE),
-                              col = color.palette(length(levels) - 1),
-                              asp = NA,
-                              xaxs = "i",
-                              yaxs = "i",
-                              ...) {
-  plot.new()
-  plot.window(xlim, ylim, "", xaxs = xaxs, yaxs = yaxs, asp = asp, ...)
-  if (!is.matrix(z) || nrow(z) <= 1 || ncol(z) <= 1)
-    stop("no proper 'z' matrix specified")
-  if (!is.double(z))  storage.mode(z) <- "double"
-  .filled.contour(as.double(x), as.double(y), z, as.double(levels),
-                  col = col)
-  title(...)
-  axis(1, ...)
-  axis(2, ...)
+filled.contour.mod = function(
+  x = seq(0, 1, len = nrow(z)),
+  y = seq(0, 1, len = ncol(z)),
+  z,
+  xlim = range(x, finite = TRUE),
+  ylim = range(y, finite = TRUE),
+  zlim = range(z, finite = TRUE),
+  levels = pretty(zlim, nlevels),
+  nlevels = 30,
+  color.palette = function(n) grDevices::hcl.colors(n, "YlOrRd", rev = TRUE),
+  col = color.palette(length(levels) - 1),
+  asp = NA,
+  xaxs = "i",
+  yaxs = "i",
+  log = '',
+  axisX = TRUE,
+  axisY = TRUE,
+  ...
+) {
+  suppressWarnings({
+    plot.new()
+    plot.window(xlim, ylim, "", xaxs = xaxs, yaxs = yaxs,
+                asp = asp, log = log, ...)
+    if (!is.matrix(z) || nrow(z) <= 1 || ncol(z) <= 1)
+      stop("no proper 'z' matrix specified")
+    if (!is.double(z))  storage.mode(z) = "double"
+    .filled.contour(as.double(x), as.double(y), z, as.double(levels), col = col)
+    title(...)
+    if (axisX) axis(1, ...)
+    if (axisY) axis(2, ...)
+  })
   invisible()
 }
 
